# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/ratelimit.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/ratelimit.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import options_pb2 as gateway_dot_options__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gateway/ratelimit.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd1\x03\n\tRatelimit\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x31\n\ndeployment\x18\x02 \x01(\tB\x1d\xe2\x41\x02\x02\x05\xbaH\x04r\x02\x10\x01\xc2\xf1\x04\ridx_ratelimit\x12\'\n\x07\x61\x63\x63ount\x18\x03 \x01(\tB\x16\xe2\x41\x02\x01\x05\xc2\xf1\x04\ridx_ratelimit\x12-\n\x06metric\x18\x04 \x01(\tB\x1d\xe2\x41\x02\x02\x05\xbaH\x04r\x02\x10\x01\xc2\xf1\x04\ridx_ratelimit\x12\x1d\n\x05limit\x18\x05 \x01(\x02\x42\x0e\xe2\x41\x01\x01\xbaH\x07\n\x05-\x00\x00\x80\xbf\x12\x1b\n\ris_soft_limit\x18\x06 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12#\n\x0breservation\x18\x07 \x01(\x02\x42\x0e\xe2\x41\x01\x01\xbaH\x07\n\x05-\x00\x00\x80\xbf\x12\x36\n\x0b\x63reate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03:T\xea\x41M\n\x1a\x61pi.fireworks.ai/Ratelimit\x12\x18ratelimits/{RatelimitId}*\nratelimits2\tratelimit\x82\xf1\x04\x00\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.ratelimit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_RATELIMIT'].fields_by_name['name']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_RATELIMIT'].fields_by_name['deployment']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['deployment']._serialized_options = b'\342A\002\002\005\272H\004r\002\020\001\302\361\004\ridx_ratelimit'
  _globals['_RATELIMIT'].fields_by_name['account']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['account']._serialized_options = b'\342A\002\001\005\302\361\004\ridx_ratelimit'
  _globals['_RATELIMIT'].fields_by_name['metric']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['metric']._serialized_options = b'\342A\002\002\005\272H\004r\002\020\001\302\361\004\ridx_ratelimit'
  _globals['_RATELIMIT'].fields_by_name['limit']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['limit']._serialized_options = b'\342A\001\001\272H\007\n\005-\000\000\200\277'
  _globals['_RATELIMIT'].fields_by_name['is_soft_limit']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['is_soft_limit']._serialized_options = b'\342A\001\001'
  _globals['_RATELIMIT'].fields_by_name['reservation']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['reservation']._serialized_options = b'\342A\001\001\272H\007\n\005-\000\000\200\277'
  _globals['_RATELIMIT'].fields_by_name['create_time']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_RATELIMIT'].fields_by_name['update_time']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_RATELIMIT']._loaded_options = None
  _globals['_RATELIMIT']._serialized_options = b'\352AM\n\032api.fireworks.ai/Ratelimit\022\030ratelimits/{RatelimitId}*\nratelimits2\tratelimit\202\361\004\000'
  _globals['_RATELIMIT']._serialized_start=182
  _globals['_RATELIMIT']._serialized_end=647
# @@protoc_insertion_point(module_scope)
