# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/workload.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/workload.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from ..google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from ..google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from ..google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gateway/workload.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x18gateway/deployment.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfe\t\n\x08Workload\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x0b\xe2\x41\x01\x01\xbaH\x04r\x02\x18?\x12!\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x0c\xe2\x41\x01\x01\xbaH\x05r\x03\x18\xe7\x07\x12\x36\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x35\n\x0b\x65xpire_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x01\x12\x35\n\npurge_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x36\n\x0b\x64\x65lete_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12+\n\ncreated_by\x18\t \x01(\tB\x17\xe2\x41\x02\x03\x05\xfa\xd2\xe4\x93\x02\x0c\x12\nOWNER_ONLY\x12-\n\x05state\x18\n \x01(\x0e\x32\x17.gateway.Workload.StateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x0b \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12S\n\x0b\x61nnotations\x18\x0c \x03(\x0b\x32\".gateway.Workload.AnnotationsEntryB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12,\n\tplacement\x18\r \x01(\x0b\x32\x12.gateway.PlacementB\x05\xe2\x41\x02\x01\x05\x12*\n\x11min_replica_count\x18\x0e \x01(\x05\x42\x0f\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xa8\xf1\x04\x01\x12-\n\x11max_replica_count\x18\x0f \x01(\x05\x42\x12\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\xe8\x07(\x00\xa8\xf1\x04\x01\x12\x44\n\x15\x64\x65sired_replica_count\x18\x10 \x01(\x05\x42%\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\xe8\x07(\x00\xa8\xf1\x04\x01\xfa\xd2\xe4\x93\x02\r\x12\x0bOUTPUT_ONLY\x12=\n\x12\x61utoscaling_policy\x18\x11 \x01(\x0b\x32\x1a.gateway.AutoscalingPolicyB\x05\xe2\x41\x02\x01\x05\x12\x1d\n\x0eworkload_shape\x18\x12 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12\x36\n\x12\x64isable_accounting\x18\x13 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x31\n\x0c\x66or_training\x18\x14 \x01(\x08\x42\x1b\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"l\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\x0c\n\x08UPDATING\x10\x05\x12\x0b\n\x07\x44\x45LETED\x10\x06:o\xea\x41]\n\x19\x61pi.fireworks.ai/Workload\x12+accounts/{AccountId}/workloads/{WorkloadId}*\tworkloads2\x08workload\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"s\n\x15\x43reateWorkloadRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12)\n\x08workload\x18\x02 \x01(\x0b\x32\x11.gateway.WorkloadB\x04\xe2\x41\x01\x02\x12\x19\n\x0bworkload_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"]\n\x12GetWorkloadRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x33\n\tread_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"\x8b\x02\n\x14ListWorkloadsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x0cshow_deleted\x18\x06 \x01(\x08\x12\x31\n\rshow_internal\x18\x07 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x33\n\tread_mask\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"j\n\x15ListWorkloadsResponse\x12$\n\tworkloads\x18\x01 \x03(\x0b\x32\x11.gateway.Workload\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"y\n\x15UpdateWorkloadRequest\x12)\n\x08workload\x18\x01 \x01(\x0b\x32\x11.gateway.WorkloadB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"\\\n\x15\x44\x65leteWorkloadRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x12\n\x04hard\x18\x02 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12\x1b\n\rignore_checks\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.workload_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_WORKLOAD_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_WORKLOAD_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_WORKLOAD'].fields_by_name['name']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_WORKLOAD'].fields_by_name['display_name']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['display_name']._serialized_options = b'\342A\001\001\272H\004r\002\030?'
  _globals['_WORKLOAD'].fields_by_name['description']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['description']._serialized_options = b'\342A\001\001\272H\005r\003\030\347\007'
  _globals['_WORKLOAD'].fields_by_name['create_time']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_WORKLOAD'].fields_by_name['update_time']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_WORKLOAD'].fields_by_name['expire_time']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['expire_time']._serialized_options = b'\342A\001\001'
  _globals['_WORKLOAD'].fields_by_name['purge_time']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['purge_time']._serialized_options = b'\342A\002\003\005'
  _globals['_WORKLOAD'].fields_by_name['delete_time']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['delete_time']._serialized_options = b'\342A\002\003\005'
  _globals['_WORKLOAD'].fields_by_name['created_by']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005\372\322\344\223\002\014\022\nOWNER_ONLY'
  _globals['_WORKLOAD'].fields_by_name['state']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_WORKLOAD'].fields_by_name['status']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_WORKLOAD'].fields_by_name['annotations']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['annotations']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOAD'].fields_by_name['placement']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['placement']._serialized_options = b'\342A\002\001\005'
  _globals['_WORKLOAD'].fields_by_name['min_replica_count']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['min_replica_count']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\250\361\004\001'
  _globals['_WORKLOAD'].fields_by_name['max_replica_count']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['max_replica_count']._serialized_options = b'\342A\001\001\272H\007\032\005\030\350\007(\000\250\361\004\001'
  _globals['_WORKLOAD'].fields_by_name['desired_replica_count']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['desired_replica_count']._serialized_options = b'\342A\001\001\272H\007\032\005\030\350\007(\000\250\361\004\001\372\322\344\223\002\r\022\013OUTPUT_ONLY'
  _globals['_WORKLOAD'].fields_by_name['autoscaling_policy']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['autoscaling_policy']._serialized_options = b'\342A\002\001\005'
  _globals['_WORKLOAD'].fields_by_name['workload_shape']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['workload_shape']._serialized_options = b'\342A\002\002\005'
  _globals['_WORKLOAD'].fields_by_name['disable_accounting']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['disable_accounting']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOAD'].fields_by_name['for_training']._loaded_options = None
  _globals['_WORKLOAD'].fields_by_name['for_training']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOAD']._loaded_options = None
  _globals['_WORKLOAD']._serialized_options = b'\352A]\n\031api.fireworks.ai/Workload\022+accounts/{AccountId}/workloads/{WorkloadId}*\tworkloads2\010workload\202\361\004\013\n\007Account\030\001'
  _globals['_CREATEWORKLOADREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEWORKLOADREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEWORKLOADREQUEST'].fields_by_name['workload']._loaded_options = None
  _globals['_CREATEWORKLOADREQUEST'].fields_by_name['workload']._serialized_options = b'\342A\001\002'
  _globals['_CREATEWORKLOADREQUEST'].fields_by_name['workload_id']._loaded_options = None
  _globals['_CREATEWORKLOADREQUEST'].fields_by_name['workload_id']._serialized_options = b'\342A\001\001'
  _globals['_GETWORKLOADREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETWORKLOADREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETWORKLOADREQUEST'].fields_by_name['read_mask']._loaded_options = None
  _globals['_GETWORKLOADREQUEST'].fields_by_name['read_mask']._serialized_options = b'\342A\001\001'
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['show_internal']._loaded_options = None
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['show_internal']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['read_mask']._loaded_options = None
  _globals['_LISTWORKLOADSREQUEST'].fields_by_name['read_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEWORKLOADREQUEST'].fields_by_name['workload']._loaded_options = None
  _globals['_UPDATEWORKLOADREQUEST'].fields_by_name['workload']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEWORKLOADREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEWORKLOADREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEWORKLOADREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEWORKLOADREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_DELETEWORKLOADREQUEST'].fields_by_name['hard']._loaded_options = None
  _globals['_DELETEWORKLOADREQUEST'].fields_by_name['hard']._serialized_options = b'\342A\001\001'
  _globals['_DELETEWORKLOADREQUEST'].fields_by_name['ignore_checks']._loaded_options = None
  _globals['_DELETEWORKLOADREQUEST'].fields_by_name['ignore_checks']._serialized_options = b'\342A\001\001'
  _globals['_WORKLOAD']._serialized_start=292
  _globals['_WORKLOAD']._serialized_end=1570
  _globals['_WORKLOAD_ANNOTATIONSENTRY']._serialized_start=1297
  _globals['_WORKLOAD_ANNOTATIONSENTRY']._serialized_end=1347
  _globals['_WORKLOAD_STATE']._serialized_start=1349
  _globals['_WORKLOAD_STATE']._serialized_end=1457
  _globals['_CREATEWORKLOADREQUEST']._serialized_start=1572
  _globals['_CREATEWORKLOADREQUEST']._serialized_end=1687
  _globals['_GETWORKLOADREQUEST']._serialized_start=1689
  _globals['_GETWORKLOADREQUEST']._serialized_end=1782
  _globals['_LISTWORKLOADSREQUEST']._serialized_start=1785
  _globals['_LISTWORKLOADSREQUEST']._serialized_end=2052
  _globals['_LISTWORKLOADSRESPONSE']._serialized_start=2054
  _globals['_LISTWORKLOADSRESPONSE']._serialized_end=2160
  _globals['_UPDATEWORKLOADREQUEST']._serialized_start=2162
  _globals['_UPDATEWORKLOADREQUEST']._serialized_end=2283
  _globals['_DELETEWORKLOADREQUEST']._serialized_start=2285
  _globals['_DELETEWORKLOADREQUEST']._serialized_end=2377
# @@protoc_insertion_point(module_scope)
